@@ -14,7 +14,7 @@ our %EXPORT_TAGS = (
 );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{all} } );
 
-use version 0.77 (); our $VERSION = version->declare('v2.0.1_03');
+use version 0.77; our $VERSION = qv('v2.0_2');
 
 use constant OK         => 0;
 use constant WARNING    => 1;
@@ -23,7 +23,7 @@ use constant UNKNOWN    => 3;
 use constant DEPENDENT  => 4;
 
 require XSLoader;
-XSLoader::load('Net::NSCAng::Client', "$VERSION");
+XSLoader::load('Net::NSCAng::Client', $VERSION);
 
 =head1 NAME
 
@@ -113,13 +113,10 @@ connection setup. Default is 10.
 sub new {
     my ($class, $host, $identity, $psk) = splice(@_, 0, 4);
     my %args = @_%2 ? %{$_[0]} : @_;
-    @_ = (
-        $class,
-        $host, $args{port} // 5668, $identity, $psk,
+    $class->_new($host, $args{port} // 5668, $identity, $psk,
         @args{qw/ ciphers node_name svc_description /},
         $args{timeout} // 10,
     );
-    goto &_new;
 }
 
 =head2 svc_result
